baseObjects.Record

|  | ## Cheshire3 Object Model: Class Record

Module baseObjects :: Class Record

## Class Record
source code

Known Subclasses:
  record.DomRecord, record.MarcRecord, record.SaxRecord

Records in the system are stored in an XML form. Attached to the record is various configurable metadata, such as the time it was inserted into the database and by which user. Records are stored in a RecordStore database and retrieved via a persistent and unique document identifier. The record data may be retrieved as a list of SAX events, as regularised XML or as a DOM tree.
Instance Methods

__init__(self, data, xml, docid=None)
get_dom(self) Return the DOM document node for the record.
get_sax(self) Return the list of SAX events for the record, serialised according to the internal C3 format.
get_xml(self) Return the XML for the record as a serialised string.
process_xpath(self, xpath, maps={}) Process the given xpath (either string or compiled), perhaps with some supplied namespace mappings.

Class Variables

baseUri |
dom |
elementHash |
history |
parent |
processHistory |
recordStore |
resultSetItem |
rights |
sax |
schema |
schemaType |
status |
xml |

Method Details

### __init__(self, data, xml, docid=None) (Constructor) | source code

### get_dom(self) | source code
Return the DOM document node for the record.

### get_sax(self) | source code
Return the list of SAX events for the record, serialised according to the internal C3 format.

### get_xml(self) | source code
Return the XML for the record as a serialised string.

### process_xpath(self, xpath, maps={}) | source code
Process the given xpath (either string or compiled), perhaps with some supplied namespace mappings.

Class Variable Details

    ### baseUri Value:
        ''

    ### dom Value:
        None

    ### elementHash Value:
        {}

    ### history Value:
        []

    ### parent Value:
        ('', None, 0)

    ### processHistory Value:
        []

    ### recordStore Value:
        None

    ### resultSetItem Value:
        None

    ### rights Value:
        []

    ### sax Value:
        []

    ### schema Value:
        ''

    ### schemaType Value:
        ''

    ### status Value:
        ''

    ### xml Value:
        ''